@@ -888,9 +888,6 @@ class Main:
         offset = self.readLong(f)
         f.seek( offset )
         salt = f.read( self.saltSize )
-        # not valid for version 4 ?
-        #self.iter = self.readShort(f)
-        #self.cypher = self.readShort(f)
         hash = f.read( self.hashSize )
         
         return ( name, dbAttr, version, crDate, modDate, modNumber, appInfoID, 
@@ -903,7 +900,11 @@ class Main:
         if self.salt == None :
             print "no salt - generating some"
             random.seed()
-            self.salt = str( random.getrandbits( self.saltSize*8 ))
+            self.salt = ''
+            salt = random.getrandbits( self.saltSize*8 )
+            for i in range( self.saltSize ) :
+                self.salt = self.salt + chr( salt >> ( self.saltSize - i ) & 0xFF )
+#            print "salt:", str( self.salt )
             m = hashlib.md5()
             m.update( self.salt )
             m.update( password )
